package xyz.tbvns.ui;

import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.Node;
import javafx.scene.control.Label;
import javafx.scene.control.ScrollPane;
import javafx.scene.layout.*;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import lombok.extern.slf4j.Slf4j;
import xyz.tbvns.core.DataManager;
import xyz.tbvns.core.Objects.Level;

import java.util.List;

@Slf4j
public class LevelSelectScreen {
    public static Label label = new Label("Select the level to edit:");
    public static Pane pane() {
        FlowPane pane = new FlowPane();
        pane.setAlignment(Pos.TOP_CENTER);
        pane.setPrefWidth(5000);
        pane.setMinWidth(400);
        pane.setMinHeight(400);

        label.setPadding(new Insets(10));
        label.setFont(Font.font(50));

        pane.getChildren().add(label);
        pane.getChildren().add(getScrollPane());

        return pane;
    }

    public static ScrollPane scrollPane = new ScrollPane();
    public static GridPane gridPane = new GridPane();

    static private ScrollPane getScrollPane() {
        gridPane.setAlignment(Pos.TOP_CENTER);

        scrollPane.setContent(gridPane);
        scrollPane.fitToWidthProperty().set(true);
        gridPane.setBackground(new Background(new BackgroundFill(new Color(1, 1, 1, 1), new CornerRadii(10), Insets.EMPTY)));

        try {
            List<Level> levelList = DataManager.getLevels();
            for (int i = 0; i < levelList.size(); i++) {
                Level level = levelList.get(i);
                gridPane.add(getLevelPane(level, i), 1, i);
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

        return scrollPane;
    }

    static private int selected = -1;
    static private Pane getLevelPane(Level level, int index) {
        GridPane pane = new GridPane(2, 2);
        Label title = new Label(level.getName());
        title.setFont(Font.font(30));
        Label creator = new Label(level.getCreator());
        creator.setFont(Font.font(20));
        pane.add(title, 1, 1);
        pane.add(creator, 1, 2);

        pane.setOnMouseClicked(mouseEvent -> {
            if (selected == index) {
                log.info("Launched level {}", level.getName());
            }
            selected = index;
            for (Node node : pane.getParent().getChildrenUnmodifiable()) {
                ((Pane) node).setBackground(new Background(new BackgroundFill(new Color(1, 1, 1, 1), new CornerRadii(10), Insets.EMPTY)));
            }
            pane.setBackground(new Background(new BackgroundFill(new Color(0.8, 0.8, 0.8, 0.5), new CornerRadii(10), Insets.EMPTY)));
            System.out.println(level.getName());
        });

        return pane;
    }
}
